==> haskell-xml-conduit-1.3.4-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xml-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.4
id: xml-conduit-1.3.4-978b9ab149c55d47c395c4e421ee22a7
key: xmlco_Is0wkxVmnS566BcT8bqkkE
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
hs-libraries: HSxml-conduit-1.3.4-Is0wkxVmnS566BcT8bqkkE
depends:
    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-c95586b34c41769092e7d9cdd505a61e
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.3.4-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xml-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.4
id: xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
key: xmlco_2zxzwJ6uwOxLR6gzh8upC0
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
hs-libraries: HSxml-conduit-1.3.4-2zxzwJ6uwOxLR6gzh8upC0
depends:
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-c95586b34c41769092e7d9cdd505a61e
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
